@@ -5,14 +5,16 @@ from os import EX_USAGE
 from pathlib import Path
 from uuid import uuid4
 from random import choice as random_choice, choices as random_choices
-from shutil import copytree
+from shutil import copytree, rmtree
 
+# noinspection PyPackageRequirements
 import click
 
 # Exempting Bandit security issue (Using Element to parse untrusted XML data is known to be vulnerable to XML attacks)
 #
 # We don't currently allow untrusted/user-provided XML so this is not a risk
 from lxml.etree import ElementTree, ProcessingInstruction, fromstring, tostring  # nosec
+from importlib_resources import path as resource_path
 from click import Abort
 from click_spinner import spinner
 from faker import Faker
@@ -36,6 +38,7 @@ from scar_add_metadata_toolbox.csw import (
     CSWAuthMissingException,
     CSWAuthInsufficientException,
     CSWAuthException,
+    CSWDatabasePostGISExtensionUnavailable,
 )
 from scar_add_metadata_toolbox.utils import aws_cli
 
@@ -85,9 +88,7 @@ def list_records():
 @click.argument("record_path", type=click.Path(exists=True, dir_okay=False))
 @click.option("--allow-update", is_flag=True, help="Update any existing record.")
 @click.option("--publish", is_flag=True, help="Publish record after importing.")
-@click.option(
-    "--allow-republish", is_flag=True, help="Republish any existing, published, record.",
-)
+@click.option("--allow-republish", is_flag=True, help="Republish any existing, published, record.")
 @click.pass_context
 def import_record(
     ctx, record_path: str, allow_update: bool = False, publish: bool = False, allow_republish: bool = False
@@ -135,9 +136,7 @@ def import_record(
 @click.argument("records_path", type=click.Path(exists=True, file_okay=False))
 @click.option("--allow-update", is_flag=True, help="Update any existing records.")
 @click.option("--publish", is_flag=True, help="Publish records after importing.")
-@click.option(
-    "--allow-republish", is_flag=True, help="Republish any existing, published, records.",
-)
+@click.option("--allow-republish", is_flag=True, help="Republish any existing, published, records.")
 @click.pass_context
 def import_records(
     ctx, records_path: str, allow_update: bool = False, publish: bool = False, allow_republish: bool = False
@@ -163,9 +162,7 @@ def import_records(
 
 @record_commands_blueprint.cli.command("publish")
 @click.argument("record-identifier")
-@click.option(
-    "--allow-republish", is_flag=True, help="Republish any existing, published, record.",
-)
+@click.option("--allow-republish", is_flag=True, help="Republish any existing, published, record.")
 def publish_record(record_identifier: str, allow_republish: bool = False):
     """Publish a record."""
     try:
@@ -200,9 +197,7 @@ def publish_record(record_identifier: str, allow_republish: bool = False):
 
 
 @record_commands_blueprint.cli.command("bulk-publish")
-@click.option(
-    "--force-republish", is_flag=True, help="Republish all existing records too.",
-)
+@click.option("--force-republish", is_flag=True, help="Republish all existing records too.")
 @click.pass_context
 def publish_records(ctx, force_republish: bool = False):
     """Publish all (un)published records."""
@@ -214,9 +209,7 @@ def publish_records(ctx, force_republish: bool = False):
     _record_count = 1
     for record_identifier in record_identifiers:
         print(f"# Record {_record_count}/{len(record_identifiers)}")
-        ctx.invoke(
-            publish_record, record_identifier=record_identifier, allow_republish=force_republish,
-        )
+        ctx.invoke(publish_record, record_identifier=record_identifier, allow_republish=force_republish)
         _record_count += 1
     print(f"Ok. {len(record_identifiers)} records (re)published.")
 
@@ -576,12 +569,12 @@ site_commands_blueprint.cli.short_help = "Manage static site."
 # noinspection PyUnresolvedReferences
 @site_commands_blueprint.cli.command("build-items")
 def build_items():
-    """Build pages for all items."""
+    """Build pages for all published items."""
     items_output_path = Path(current_app.config["SITE_PATH"]).joinpath("items")
 
     try:
         with spinner():
-            _records = list(current_app.records.retrieve_records())
+            _records = list(current_app.records.retrieve_published_records())
 
         print(f"{len(_records)} item pages to generate.")
         _items_count = 1
@@ -656,13 +649,13 @@ def build_collections():
 
 @site_commands_blueprint.cli.command("build-records")
 def build_records():
-    """Build pages for all records (XML)."""
+    """Build pages for all published records (XML)."""
     stylesheets = ["iso-html", "iso-rubric", "iso-xml"]
     records_output_path = Path(current_app.config["SITE_PATH"]).joinpath("records")
 
     try:
         with spinner():
-            records = list(current_app.records.retrieve_records())
+            records = list(current_app.records.retrieve_published_records())
 
         print(f"{len(records) * len(stylesheets)} record pages to generate.")
         _records_count = 1
@@ -746,14 +739,13 @@ def build_pages():
 @site_commands_blueprint.cli.command("copy-assets")
 def copy_assets():
     """Copy all static assets (CSS, JS, etc.)."""
-    # workaround for lack of `dirs_exist_ok` option in Python 3.6
+    # workaround for lack of `dirs_exist_ok` option in copytree in Python 3.6
     try:
-        Path(current_app.config["SITE_PATH"]).joinpath("static").unlink()
+        rmtree(Path(current_app.config["SITE_PATH"]).joinpath("static"))
     except FileNotFoundError:
         pass
-    copytree(
-        str(Path("./scar_add_metadata_toolbox/static")), str(Path(current_app.config["SITE_PATH"]).joinpath("static"))
-    )
+    with resource_path("scar_add_metadata_toolbox", "static") as static_dir:
+        copytree(str(Path(static_dir)), str(Path(current_app.config["SITE_PATH"]).joinpath("static")))
     print("Ok. static assets copied.")
 
 
@@ -812,6 +804,10 @@ def setup_catalogue(catalogue: str):
         sys_exit(EX_USAGE)
     except CSWDatabaseAlreadyInitialisedException:
         print(f"Ok. Note CSW catalogue '{catalogue}' is already setup.")
+    except CSWDatabasePostGISExtensionUnavailable:  # pragma: no cover (will be addressed in #116)
+        print(
+            f"No. CSW backing database does not have the PostGIS extension enabled. Enable this extension and try again."
+        )
 
 
 auth_commands_blueprint = Blueprint("auth", __name__)
