@@ -43,7 +43,7 @@ class Config:
         If true errors and uncaught exceptions will be reported to Sentry. A default value is set on an per-environment 
         basis (off in development/testing) by overriding the attribute, however it can be also be set at runtime.
         """
-        self.APP_ENABLE_SENTRY = str2bool(os.environ.get("APP_ENABLE_SENTRY") or self._APP_ENABLE_SENTRY)
+        self.APP_ENABLE_SENTRY = str2bool(os.environ.get("APP_ENABLE_SENTRY") or str(self._APP_ENABLE_SENTRY))
 
         """
         AUTH_SESSION_FILE_PATH - Path to the file used to store authentication information
@@ -443,8 +443,8 @@ class DevelopmentConfig(Config):  # pragma: no cover
 
     @property
     def S3_BUCKET(self) -> str:
-        if "S3_BUCKET" in os.environ:
-            return os.environ["S3_BUCKET"]
+        if "APP_S3_BUCKET" in os.environ:
+            return os.environ["APP_S3_BUCKET"]
         return "add-catalogue-integration.data.bas.ac.uk"
 
 
